@@ -2,7 +2,7 @@
 Container for object classes used in cs18-api-client
 """
 import abc
-from typing import List
+from typing import List, Optional
 import dateutil.parser
 
 from common.assertion_helper import AssertionHelper
@@ -185,7 +185,7 @@ class TerraformModuleDescriptor:
 
 
 class SpaceTerraformModuleInput:
-    def __init__(self, name: str, value: str, overridable: bool) -> None:
+    def __init__(self, name: str, value: Optional[str], overridable: bool) -> None:
         self.name = name
         self.value = value
         self.overridable = overridable
