@@ -177,13 +177,15 @@ class BlueprintServiceResponse:
 
 class BlueprintInputResponse:
     def __init__(
-            self, name: str, default_value: str, display_style: str, description: str, optional: bool
+            self, name: str, default_value: str, display_style: str, description: str, optional: bool,
+            possible_values: []
     ):
         self.name = name
         self.default_value = default_value
         self.display_style = display_style
         self.optional = optional
         self.description = description
+        self.possible_values = possible_values
 
 
 class BlueprintRegionResponse:
@@ -539,6 +541,29 @@ class ServiceResponse:
         self.status = status
         self.progress = progress
         self.logs = logs
+        
+
+class CustomTagResponse:
+    def __init__(self,
+                 name: str,
+                 value: str,
+                 scope: str,
+                 possible_values: [],
+                 description: str,
+                 modified_by: str,
+                 last_modified: datetime,
+                 created_by: str,
+                 created_date: datetime,
+                 ):
+        self.name = name
+        self.value = value
+        self.scope = scope
+        self.possible_values = possible_values
+        self.description = description
+        self.modified_by = modified_by
+        self.last_modified = last_modified
+        self.created_date = created_date
+        self.created_by = created_by
 
 
 class SandboxResponse(SandboxResponseBase):
@@ -564,7 +589,8 @@ class SandboxResponse(SandboxResponseBase):
                  launching_progress: LaunchingProgress,
                  source: BlueprintSourceResponse,
                  direct_access: str,
-                 outputs: Optional[List[SandboxOutput]]):
+                 outputs: Optional[List[SandboxOutput]],
+                 tags: List[CustomTagResponse]):
         super().__init__(sandbox_status,
                          create_time,
                          start_time,
@@ -587,6 +613,7 @@ class SandboxResponse(SandboxResponseBase):
         self.services = services
         self.launching_progress = launching_progress
         self.outputs = outputs
+        self.tags = tags
 
 
 class SandboxResponseLean(SandboxResponseBase):
@@ -686,7 +713,8 @@ class ProductionResponse(metaclass=abc.ABCMeta):
             debugging_service: str,
             launching_progress: LaunchingProgress,
             direct_access: str,
-            outputs: Optional[List[SandboxOutput]]):
+            outputs: Optional[List[SandboxOutput]],
+            tags: List[CustomTagResponse]):
         self.production_id = production_id
         self.sandbox_id = sandbox_id
         self.name = name
@@ -710,6 +738,7 @@ class ProductionResponse(metaclass=abc.ABCMeta):
         self.launching_progress = launching_progress
         self.direct_access = direct_access
         self.outputs = outputs
+        self.tags = tags
 
 
 class ProductionBlueResponse(ProductionResponse):
@@ -737,7 +766,8 @@ class ProductionBlueResponse(ProductionResponse):
                  debugging_service: str,
                  launching_progress: LaunchingProgress,
                  direct_access: str,
-                 outputs: Optional[List[SandboxOutput]]):
+                 outputs: Optional[List[SandboxOutput]],
+                 tags: List[CustomTagResponse]):
         super().__init__(
             production_id=production_id,
             sandbox_id=sandbox_id,
@@ -761,7 +791,8 @@ class ProductionBlueResponse(ProductionResponse):
             debugging_service=debugging_service,
             launching_progress=launching_progress,
             direct_access=direct_access,
-            outputs=outputs)
+            outputs=outputs,
+            tags=tags)
         self.has_green = has_green
 
 
@@ -790,7 +821,8 @@ class ProductionGreenResponse(ProductionResponse):
                  debugging_service: str,
                  launching_progress: LaunchingProgress,
                  direct_access: str,
-                 outputs: Optional[List[SandboxOutput]]):
+                 outputs: Optional[List[SandboxOutput]],
+                 tags: List[CustomTagResponse]):
         super().__init__(
             production_id=production_id,
             sandbox_id=sandbox_id,
@@ -814,7 +846,8 @@ class ProductionGreenResponse(ProductionResponse):
             debugging_service=debugging_service,
             launching_progress=launching_progress,
             direct_access=direct_access,
-            outputs=outputs)
+            outputs=outputs,
+            tags=tags)
         self.exposure = exposure
 
 
@@ -1266,27 +1299,7 @@ class CreateAccountFinalizeResponse:
         self.last_name = last_name
 
 
-class CustomTagResponse:
-    def __init__(self,
-                 name: str,
-                 value: str,
-                 scope: str,
-                 possible_values: [],
-                 description: str,
-                 modified_by: str,
-                 last_modified: datetime,
-                 created_by: str,
-                 created_date: datetime,
-                 ):
-        self.name = name
-        self.value = value
-        self.scope = scope
-        self.possible_values = possible_values
-        self.description = description
-        self.modified_by = modified_by
-        self.last_modified = last_modified
-        self.created_date = created_date
-        self.created_by = created_by
+
 
 
 class CustomTagOverrideResponse:
