@@ -32,6 +32,14 @@ class ServiceStatus:
     VALIDATION_FAILED = "ValidationFailed"
 
 
+class TfStageStatus:
+    PENDING = "Pending"
+    EXECUTING = "Executing"
+    DONE = "Done"
+    ERROR = "Error"
+    SKIPPED = "Skipped"
+
+
 class SandboxDeploymentStatus:
     WAITING = "Waiting"
     INITIATING = "Initiating"
